@@ -5,13 +5,14 @@
 
 package PDL::Core::Dev;
 
-use English; use Exporter; use DynaLoader; 
-@ISA    = qw( Exporter DynaLoader ); 
+use English; use Exporter; use DynaLoader;
+@ISA    = qw( Exporter DynaLoader );
 
 @EXPORT = qw(genpp %PDL_DATATYPES PDL_INCLUDE PDL_TYPEMAP
 		 PDL_INST_INCLUDE PDL_INST_TYPEMAP
 		 pdlpp_postamble_int pdlpp_stdargs_int
-		 pdlpp_postamble pdlpp_stdargs
+		 pdlpp_postamble pdlpp_stdargs write_dummy_make
+	         unsupported
 		 );
 
 # Installation locations
@@ -44,7 +45,7 @@ PDL::Types->import();
 
 %PDL_DATATYPES = ();
 foreach $key (keys %PDL::Types::typehash) {
-  $PDL_DATATYPES{$PDL::Types::typehash{$key}->{'sym'}} = 
+  $PDL_DATATYPES{$PDL::Types::typehash{$key}->{'sym'}} =
     $PDL::Types::typehash{$key}->{'ctype'};
 }
 
@@ -64,7 +65,7 @@ $O_NONBLOCK = defined $Config{'o_nonblock'} ? $Config{'o_nonblock'}
 #    pdl x;
 #    GENERICLOOP(x.datatype)
 #       generic *xx = x.data;
-#       for(i=0; i<nvals; i++) 
+#       for(i=0; i<nvals; i++)
 #          xx[i] = i/nvals;
 #    ENDGENERICLOOP
 #
@@ -72,16 +73,16 @@ $O_NONBLOCK = defined $Config{'o_nonblock'} ? $Config{'o_nonblock'}
 #
 #     pdl x;
 #     switch (x.datatype) {
-# 
+#
 #     case PDL_L:
-#        {   
+#        {
 #           long *xx = x.data;
-#           for(i=0; i<nvals; i++) 
+#           for(i=0; i<nvals; i++)
 #              xx[i] = i/nvals;
 #        }break;
-# 
+#
 #     case PDL_F:
-#        {   
+#        {
 #           float *xx = x.data;
 #
 #       .... etc. .....
@@ -91,7 +92,7 @@ $O_NONBLOCK = defined $Config{'o_nonblock'} ? $Config{'o_nonblock'}
 # This is used in PDL to write generic functions (taking pdl or void
 # objects) which is still efficient with perl writing the actual C
 # code for each type.
-# 
+#
 #     1st version - Karl Glazebrook 4/Aug/1996.
 #
 # Also makes the followings substitutions:
@@ -103,66 +104,64 @@ $O_NONBLOCK = defined $Config{'o_nonblock'} ? $Config{'o_nonblock'}
 sub genpp {
 
    $gotstart = 0; @gencode = ();
-   
+
    while (<>) { # Process files in @ARGV list - result to STDOUT
-   
+
       # Do the miscellaneous substitutions first
-   
+
       s/O_NONBLOCK/$O_NONBLOCK/go;   # I/O
-   
-   
+
       if ( /(\s*)?\bGENERICLOOP\s*\(([^\)]*)\)(\s*;)?/ ){  # Start of generic code
          #print $MATCH, "=$1=\n";
-      
+
          die "Found GENERICLOOP while searching for ENDGENERICLOOP\n" if $gotstart;
          $loopvar = $2;
          $indent = $1;
          print $PREMATCH;
-         
+
          @gencode = ();  # Start saving code
          push @gencode, $POSTMATCH;
          $gotstart = 1;
          next;
       }
-      
+
       if ( /\bENDGENERICLOOP(\s*;)?/ ) {
-      
+
          die "Found ENDGENERICLOOP while searching for GENERICLOOP\n" unless $gotstart;
-      
+
          push @gencode, $PREMATCH;
-      
+
          flushgeneric();  # Output the generic code
-      
+
          print $POSTMATCH;  # End of genric code
          $gotstart = 0;
          next;
       }
-   
+
       if ($gotstart) {
          push @gencode, $_;
       }
       else {
          print;
       }
-   
+
    } # End while
-   
 }
 
 sub flushgeneric {  # Construct the generic code switch
-   
+
    print $indent,"switch ($loopvar) {\n\n";
 
    for $case (keys %PDL_DATATYPES) {
 
-     $type = $PDL_DATATYPES{$case}; 
+     $type = $PDL_DATATYPES{$case};
 
      print $indent,"case $case:\n"; # Start of this case
      print $indent,"   {";
 
      # Now output actual code with substutions
 
-     for  (@gencode) { 
+     for  (@gencode) {
         $line = $_;
 
         $line =~ s/\bgeneric\b/$type/g;
@@ -174,14 +173,41 @@ sub flushgeneric {  # Construct the generic code switch
    }
    print $indent,"default:\n";
    print $indent,'   croak ("Not a known data type code=%d",'.$loopvar.");\n";
-   print $indent,"}";   
+   print $indent,"}";
 
 }
 
 
 # Standard PDL postamble
 
-sub postamble {q~
+sub postamble {
+
+  if ($^O =~ /win32/i) {
+    open FI,'>./getdev.pl' or die "couldn't open getdev.pl";
+    my $location = whereami_any();
+    print FI << "EOD";
+
+  require \"$location/Core/Dev.pm\";
+  PDL::Core::Dev->import();				\
+  genpp();
+  1;
+EOD
+     close FI;
+     return q~
+
+# Rules for the generic preprocessor
+
+.SUFFIXES: .g
+.g.c:
+	$(PERL) -e "require './getdev.pl'" $<  > $@
+
+.c$(OBJ_EXT):
+	$(CCCMD) $(CCCDLFLAGS) -I$(PERL_INC) $(DEFINE) $*.c
+
+     ~;
+} else {
+
+q~
 
 # Rules for the generic preprocessor
 
@@ -199,17 +225,19 @@ sub postamble {q~
 
 ~;}
 
+}
+
 # Return library locations
 
 # whereami_any returns appended 'Basic' or 'PDL' dir as appropriate
 sub whereami_any {
-	&whereami(1) or &whereami_inst(1) or 
+	&whereami(1) or &whereami_inst(1) or
           die "Unable to determine ANY directory path to PDL::Core::Dev module\n";
 }
 
 sub whereami {
    for $dir (@INC,qw|. .. ../.. ../../..|) {
-      return ($_[0] ? $dir . '/Basic' : $dir) 
+      return ($_[0] ? $dir . '/Basic' : $dir)
 	if -e "$dir/Basic/Core/Dev.pm";
    }
    die "Unable to determine UNINSTALLED directory path to PDL::Core::Dev module\n"
@@ -230,7 +258,7 @@ sub whereami_inst {
 # source,    prefix,module/package
 # The idea is to support in future several packages in same dir.
 
-# This is the function internal for PDL. 
+# This is the function internal for PDL.
 # Later on, we shall provide another for use outside PDL.
 sub pdlpp_postamble_int {
 	join '',map { my($src,$pref,$mod) = @$_;
@@ -239,14 +267,14 @@ sub pdlpp_postamble_int {
 qq|
 
 $pref.xs $pref.pm: $src $w/Basic/Gen/pm_to_blib
-	\$(PERL) -I$w/blib/lib -I$w/blib/arch '-MPDL::PP qw/$mod $mod $pref/' $src
+	\$(PERL) -I$w/blib/lib -I$w/blib/arch \"-MPDL::PP qw/$mod $mod $pref/\" $src
 
 |
-	} (@_) 
+	} (@_)
 }
 
 
-# This is the function internal for PDL. 
+# This is the function internal for PDL.
 # Later on, we shall provide another for use outside PDL.
 sub pdlpp_postamble {
 	join '',map { my($src,$pref,$mod) = @$_;
@@ -254,11 +282,11 @@ sub pdlpp_postamble {
 	$w =~ s%/((PDL)|(Basic))$%%;  # remove the trailing subdir
 qq|
 
-$pref.xs $pref.pm: $src 
-	\$(PERL) -I$w/blib/lib -I$w/blib/arch '-MPDL::PP qw/$mod $mod $pref/' $src
+$pref.xs $pref.pm: $src
+	\$(PERL) -I$w/blib/lib -I$w/blib/arch \"-MPDL::PP qw/$mod $mod $pref/\" $src
 
 |
-	} (@_) 
+	} (@_)
 }
 
 sub pdlpp_stdargs_int {
@@ -269,8 +297,8 @@ sub pdlpp_stdargs_int {
  	%::PDL_OPTIONS,
 	 'NAME'  	=> $mod,
 	 'VERSION_FROM' => "$w/Basic/Core/Version.pm",
-	 'TYPEMAPS'     => [&PDL_TYPEMAP()], 
-	 'OBJECT'       => "$pref\$(OBJ_EXT)",           
+	 'TYPEMAPS'     => [&PDL_TYPEMAP()],
+	 'OBJECT'       => "$pref\$(OBJ_EXT)",
 	 PM 	=> {"$pref.pm" => "\$(INST_LIBDIR)/$pref.pm"},
 	 MAN3PODS => {"$pref.pm" => "\$(INST_MAN3DIR)/$mod.\$(MAN3EXT)"},
 	 'INC'          => &PDL_INCLUDE(),
@@ -285,8 +313,8 @@ sub pdlpp_stdargs {
  return (
  	%::PDL_OPTIONS,
 	 'NAME'  	=> $mod,
-	 'TYPEMAPS'     => [&PDL_INST_TYPEMAP()], 
-	 'OBJECT'       => "$pref\$(OBJ_EXT)",           
+	 'TYPEMAPS'     => [&PDL_INST_TYPEMAP()],
+	 'OBJECT'       => "$pref\$(OBJ_EXT)",
 	 PM 	=> {"$pref.pm" => "\$(INST_LIBDIR)/$pref.pm"},
 	 MAN3PODS => {"$pref.pm" => "\$(INST_MAN3DIR)/$mod.\$(MAN3EXT)"},
 	 'INC'          => &PDL_INST_INCLUDE(),
@@ -295,5 +323,34 @@ sub pdlpp_stdargs {
  );
 }
 
+
+sub unsupported {
+  my ($package,$os) = @_;
+  "No support for $package on $os platform yet. Will skip build process";
+}
+
+sub write_dummy_make {
+  my ($msg) = @_;
+      open(OUT,">Makefile") or die "can't open Makefile";
+      print OUT <<"EOT";
+fred:
+	\@echo ****
+	\@echo \"$msg\"
+	\@echo ****
+
+all: fred
+
+test: fred
+
+clean ::
+	-mv Makefile Makefile.old
+
+realclean ::
+	rm -rf Makefile Makefile.old
+
+EOT
+      close(OUT);
+}
+
 1; # Return OK
 
